==> mx-datetime_19.9.3.tar.xz: mx-datetime-19.9.3/translations/mx-datetime_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="596"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Datum &amp; Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Datum &amp;&amp; Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>H:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="278"/>
        <location filename="../datetime.cpp" line="296"/>
        <location filename="../datetime.cpp" line="303"/>
        <source>Hardware Clock</source>
        <translation>Hardware Uhr</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Hardware Uhr Tools</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Hole Informationen von der Hardware Uhr und zeige sie in der Box Unten.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Hardware Uhr auslesen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="303"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="306"/>
        <source>Drift Adjust</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="329"/>
        <source>Time transfer</source>
        <translation>Zeit übertragen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Jetzt die Systemzeit auf Hardware Uhrzeit setzen.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="338"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Hardware Zeit nach Systemzeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Jetzt die Hardware Uhr auf Systemzeit setzen.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Systemzeit nach Hardware Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="364"/>
        <source>Update the drift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="374"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Zeitzone für die Hardware Uhr</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="380"/>
        <source>Local time</source>
        <translation>Ortszeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="383"/>
        <source>Local</source>
        <translation>Lokal</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="390"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>UTC oder Greenwich Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="393"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="433"/>
        <source>Network Time</source>
        <translation>Netzwerk Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="439"/>
        <source>Move the selected item down</source>
        <translation>Selektion nach Unten verschieben</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="450"/>
        <source>Move the selected item up</source>
        <translation>Selektion nach Oben verschieben</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="461"/>
        <source>Remove the current item from the list</source>
        <translation>Selektion von der Liste entfernen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="472"/>
        <source>Add an item to the list</source>
        <translation>Eintrag zur Liste hinzufügen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="498"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Die Uhrzeit automatisch mit NTP Servern abgleichen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="505"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Die Uhrzeit jetzt mit NTP Servern abgleichen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="508"/>
        <source>Update Now</source>
        <translation>Jetzt abgleichen</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="520"/>
        <source>List of NTP servers to use.</source>
        <translation>Liste der benutzen NTP Server</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="536"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="541"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="546"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="270"/>
        <source>Reading...</source>
        <translation>Lese...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="284"/>
        <source>Adjusting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="296"/>
        <location filename="../datetime.cpp" line="303"/>
        <source>System Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="309"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="312"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="350"/>
        <source>Updating...</source>
        <translation>Abgleich...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="360"/>
        <source>The system clock was updated successfully.</source>
        <translation>Die Systemzeit wurde erfolgreich synchronisiert.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="362"/>
        <source>The system clock could not be updated.</source>
        <translation>Die Systemzeit konnte nicht synchronisiert werden.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="364"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Keiner der NTP Server aus der Liste ist aktiviert.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="595"/>
        <source>About MX Date &amp; Time</source>
        <translation>Über MX Datum &amp; Zeit</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="596"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="597"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Grafisches Tool zum Einstellen des Datum und der Uhrzeit in MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="599"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="600"/>
        <location filename="../datetime.cpp" line="614"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="601"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="602"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="628"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="646"/>
        <source>MX Date &amp; Time Help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-datetime_21.11.tar.xz: mx-datetime-21.11/translations/mx-datetime_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="datetime.ui" line="20"/>
        <location filename="datetime.cpp" line="596"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Datum &amp; Zeit</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="100"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Datum &amp;&amp; Zeit</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>H:mm:ss</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="278"/>
        <location filename="datetime.cpp" line="296"/>
        <location filename="datetime.cpp" line="303"/>
        <source>Hardware Clock</source>
        <translation>Hardware Uhr</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Hardware Uhr Tools</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Hole Informationen von der Hardware Uhr und zeige sie in der Box Unten.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Hardware Uhr auslesen</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="300"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Systematische Driftkorrekturen der Systemuhr durchführen.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="303"/>
        <source>Drift Adjust</source>
        <translation>Driftkorrektur</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="323"/>
        <source>Time transfer</source>
        <translation>Zeit übertragen</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="329"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Jetzt die Systemzeit auf Hardware Uhrzeit setzen.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="332"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Hardware Zeit nach Systemzeit</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="339"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Jetzt die Hardware Uhr auf Systemzeit setzen.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="342"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Systemzeit nach Hardware Zeit</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="349"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Aktualisierung des Driftfaktors beim Einstellen der Systemuhr. </translation>
    </message>
    <message>
        <location filename="datetime.ui" line="352"/>
        <source>Update the drift</source>
        <translation>Drift aktualisieren</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="362"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Zeitzone für die Hardware Uhr</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="368"/>
        <source>Local time</source>
        <translation>Ortszeit</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="371"/>
        <source>Local</source>
        <translation>Lokal</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="378"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>UTC oder Greenwich Zeit</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="381"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="421"/>
        <source>Network Time</source>
        <translation>Netzwerk Zeit</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="427"/>
        <source>Move the selected item down</source>
        <translation>Selektion nach Unten verschieben</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="438"/>
        <source>Move the selected item up</source>
        <translation>Selektion nach Oben verschieben</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="449"/>
        <source>Remove the current item from the list</source>
        <translation>Selektion von der Liste entfernen</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="460"/>
        <source>Add an item to the list</source>
        <translation>Eintrag zur Liste hinzufügen</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="486"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Die Uhrzeit automatisch mit NTP Servern abgleichen</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="493"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Die Uhrzeit jetzt mit NTP Servern abgleichen</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="496"/>
        <source>Update Now</source>
        <translation>Jetzt abgleichen</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="505"/>
        <source>List of NTP servers to use.</source>
        <translation>Liste der benutzen NTP Server</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="521"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="526"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="531"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="270"/>
        <source>Reading...</source>
        <translation>Lese...</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="284"/>
        <source>Adjusting...</source>
        <translation>Korrektur läuft ....</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="296"/>
        <location filename="datetime.cpp" line="303"/>
        <source>System Clock</source>
        <translation>Systemuhr</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="309"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>Die %1 Zeit wurde von %2 übernommen.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="312"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>Die %1 Zeit konnte von %2 nicht übernommen werden.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="350"/>
        <source>Updating...</source>
        <translation>Abgleich...</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="360"/>
        <source>The system clock was updated successfully.</source>
        <translation>Die Systemzeit wurde erfolgreich synchronisiert.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="362"/>
        <source>The system clock could not be updated.</source>
        <translation>Die Systemzeit konnte nicht synchronisiert werden.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="364"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Keiner der NTP Server aus der Liste ist aktiviert.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="595"/>
        <source>About MX Date &amp; Time</source>
        <translation>Über MX Datum &amp; Zeit</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="596"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="597"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Grafisches Tool zum Einstellen des Datum und der Uhrzeit in MX Linux</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="599"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="600"/>
        <location filename="datetime.cpp" line="614"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="601"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="602"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="628"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="646"/>
        <source>MX Date &amp; Time Help</source>
        <translation>MX Datum &amp; Zeit Hilfe</translation>
    </message>
</context>
</TS>
